@@ -8,7 +8,7 @@ try:
     from functools import cached_property
 except ImportError:
     # noinspection PyPep8Naming
-    class cached_property(object):
+    class cached_property:
         """
         A property that is only computed once per instance and then replaces itself
         with an ordinary attribute. Deleting the attribute resets the property.
