@@ -1,14 +1,15 @@
 #!/usr/bin/env python3
 # coding: utf-8
 
-import abc
 import logging
 import os
 import re
 import weakref
+from pathlib import Path
+from typing import Union
 
 from volkanic import utils
-from volkanic.compat import cached_property, abstract_property
+from volkanic.compat import cached_property
 
 _logger = logging.getLogger(__name__)
 
@@ -48,18 +49,36 @@ class _GIMeta(SingletonMeta):
         if not re.match(r'\w[\w.]*\w$', pn):
             msg = 'invalid {}.package_name: "{}"'.format(name, pn)
             raise ValueError(msg)
+        attrs['_namespaces'] = re.split(r'[._]+', pn)
         return super().__new__(mcs, name, bases, attrs)
 
 
-class _PackageNameDerivant:
+class _GINamespaces:
+    def __get__(self, _, owner: _GIMeta) -> list:
+        return getattr(owner, '_namespaces')
+
+
+class _GIName:
     __slots__ = ['sep']
-    regex = re.compile(r'[._]+')
 
     def __init__(self, sep: str):
         self.sep = sep
 
-    def __get__(self, _, owner: 'GlobalInterface'):
-        return self.regex.sub(self.sep, owner.package_name)
+    def __get__(self, _, owner: _GIMeta) -> Union[str, list]:
+        return self.sep.join(getattr(owner, '_namespaces'))
+
+
+class _GIPath:
+    __slots__ = ['func', 'result']
+
+    def __init__(self, clsmethod: classmethod):
+        self.func = clsmethod.__func__
+        self.result = self
+
+    def __get__(self, _, owner: _GIMeta) -> Path:
+        if self.result is self:
+            self.result = Path(self.func(owner))
+        return self.result
 
 
 class GlobalInterface(metaclass=_GIMeta):
@@ -68,11 +87,14 @@ class GlobalInterface(metaclass=_GIMeta):
 
     # for path and url
     # '[._]+' in package_name replaced by hyphen '-'
-    project_name = _PackageNameDerivant('-')
+    project_name = _GIName('-')
 
     # for symbols in code
     # '[._]+' in package_name replaced by underscore '_'
-    identifier = _PackageNameDerivant('_')
+    identifier = _GIName('_')
+
+    # split package_name with '[._]+'
+    namespaces = _GINamespaces()
 
     _options = {
         # for project dir locating (under_project_dir())
@@ -101,20 +123,21 @@ class GlobalInterface(metaclass=_GIMeta):
             except (KeyError, TypeError):
                 pass
 
+    # deprecated; will be remove in ver 0.5.0
     @classmethod
-    def _split_name(cls):
-        return _PackageNameDerivant.regex.split(cls.package_name)
+    def _split_name(cls) -> list:
+        return cls.namespaces
 
     @classmethod
-    def _fmt_name(cls, sep='-'):
-        return _PackageNameDerivant.regex.sub(sep, cls.package_name)
+    def _fmt_name(cls, sep='-') -> str:
+        return sep.join(cls.namespaces)
 
     @classmethod
-    def _get_conf_path_names(cls):
+    def _get_conf_path_names(cls) -> list:
         return [cls.project_name, cls._get_option('confpath_filename')]
 
     @classmethod
-    def _get_conf_paths(cls):
+    def _get_conf_paths(cls) -> list:
         """
         Make sure this method can be called without arguments.
         Override this method in your subclasses for your specific project.
@@ -125,7 +148,7 @@ class GlobalInterface(metaclass=_GIMeta):
         return [
             os.environ.get(envvar_name),
             cls.under_project_dir(names[-1]),
-            utils.under_home_dir('.' + relative_path),
+            utils.under_home_dir_hidden(relative_path),
             os.path.join('/etc', relative_path),
             os.path.join('/', relative_path),
         ]
@@ -152,11 +175,11 @@ class GlobalInterface(metaclass=_GIMeta):
                 return os.path.abspath(path)
 
     @staticmethod
-    def _parse_conf(path: str):
+    def _parse_conf(path: str) -> dict:
         return utils.load_json5_file(path)
 
     @staticmethod
-    def _check_conf(config: dict):
+    def _check_conf(config: dict) -> dict:
         return config
 
     @cached_property
@@ -190,6 +213,11 @@ class GlobalInterface(metaclass=_GIMeta):
         paths = ['..'] * n + list(paths)
         return utils.abs_path_join(pkg_dir, *paths)
 
+    # noinspection PyTypeChecker
+    package_dir = _GIPath(under_package_dir)
+    # noinspection PyTypeChecker
+    project_dir = _GIPath(under_project_dir)
+
     @classmethod
     def _get_self(cls):
         mcs = cls.__class__
@@ -238,7 +266,7 @@ class GlobalInterface(metaclass=_GIMeta):
         logging.basicConfig(level=level, format=fmt)
 
 
-class GlobalInterfaceTrial(GlobalInterface):
+class GlobalInterfaceTribal(GlobalInterface):
     package_name = 'volkanic'
 
     def _under_data_dir(self, conf_key, *paths, mkdirs=False) -> str:
@@ -265,3 +293,6 @@ class GlobalInterfaceTrial(GlobalInterface):
     def under_temp_dir(self, ext=''):
         name = os.urandom(17).hex() + ext
         return self.under_data_dir('tmp', name, mkdirs=True)
+
+
+GlobalInterfaceTrial = GlobalInterfaceTribal
